import _extends from "@babel/runtime/helpers/esm/extends";
import { forwardRef } from 'react';
import { isFragment } from 'react-is';
import cx from 'classnames';
import PropTypes from 'prop-types';
import Injector from '@s-ui/react-primitive-injector';
import Poly from '@s-ui/react-primitive-polymorphic-element';
import { useAccordionContext } from './context/index.js';
import AccordionItemHeaderChildrenDefault from './AccordionItemHeaderChildrenDefault.js';
import { BASE_CLASS_ELEMENT, BASE_CLASS_ITEM_HEADER, getBehavior, getIcon, HEADER_ICON_POSITION } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
var AccordionItemHeader = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$as = _ref.as,
    As = _ref$as === void 0 ? 'h1' : _ref$as,
    id = _ref.id,
    panelId = _ref.panelId,
    iconProp = _ref.icon,
    iconPositionProp = _ref.iconPosition,
    _ref$children = _ref.children,
    children = _ref$children === void 0 ? /*#__PURE__*/_jsx(AccordionItemHeaderChildrenDefault, {}) : _ref$children,
    animationDurationProp = _ref.animationDuration,
    value = _ref.value,
    label = _ref.label,
    level = _ref.level,
    disabled = _ref.disabled,
    onClick = _ref.onClick;
  var _useAccordionContext = useAccordionContext({
      value: value
    }),
    values = _useAccordionContext.values,
    onChange = _useAccordionContext.onChange,
    behavior = _useAccordionContext.behavior,
    setValues = _useAccordionContext.setValues,
    iconExpandedContext = _useAccordionContext.headerIconExpanded,
    iconCollapsedContext = _useAccordionContext.headerIconCollapsed,
    iconPositionContext = _useAccordionContext.headerIconPosition,
    animationDurationContext = _useAccordionContext.animationDuration;
  var handleClick = function handleClick(event) {
    var response = getBehavior(behavior)({
      value: value,
      values: values
    });
    setValues(response.values);
    [onChange, onClick].forEach(function (onHandler) {
      typeof onHandler === 'function' && onHandler(event, response);
    });
  };
  var isFragmentProp = isFragment( /*#__PURE__*/_jsx(As, {}));
  var isExpanded = values.includes(value);
  var icon = getIcon({
    icon: iconProp,
    isExpanded: isExpanded
  }, {
    iconExpanded: iconExpandedContext,
    iconCollapsed: iconCollapsedContext
  });
  var iconPosition = iconPositionProp || iconPositionContext;
  var animationDuration = animationDurationProp || animationDurationContext;
  var isHeadingElement = ['h1', 'h2', 'h3', 'h4', 'h5', 'h6'].includes(As);
  return /*#__PURE__*/_jsx(Poly, _extends({
    as: As
  }, _extends({}, !isFragmentProp && {
    className: cx(BASE_CLASS_ITEM_HEADER, BASE_CLASS_ELEMENT),
    ref: forwardedRef
  }, !isHeadingElement && !isFragmentProp && {
    role: 'heading'
  }, !isHeadingElement && level && !isFragmentProp && {
    'aria-level': level
  }, !isFragmentProp && {
    'data-expanded': isExpanded
  }, !isFragmentProp && {
    style: {
      transition: "border-radius 0s linear " + (isExpanded ? 0 : animationDuration) + "ms"
    }
  }), {
    children: /*#__PURE__*/_jsx("button", _extends({
      type: "button",
      id: id,
      className: cx(BASE_CLASS_ITEM_HEADER + "Button", BASE_CLASS_ITEM_HEADER + "Button--icon-position-" + iconPosition),
      "aria-pressed": isExpanded,
      "aria-controls": panelId
    }, _extends({}, disabled && {
      'aria-disabled': disabled,
      disabled: disabled
    }, label && {
      'aria-label': label
    }), {
      onClick: handleClick,
      children: /*#__PURE__*/_jsx(Injector, {
        headerIconExpanded: iconExpandedContext,
        headerIconCollapsed: iconCollapsedContext,
        headerIconPosition: iconPositionContext,
        disabled: disabled,
        animationDuration: animationDuration,
        icon: icon,
        iconPosition: iconPosition,
        values: values,
        value: value,
        isExpanded: values.includes(value),
        label: label,
        children: children
      })
    }))
  }));
});
AccordionItemHeader.displayName = 'AccordionItemHeader';
export default AccordionItemHeader;